# Developer Guide

Signers:

- [[msgsigner|MsgSigner]]
- [[cosignsigner|CosignSigner]]

Clients:

- [[msgsendclient|Messaging SendClient]]
- [[msgrecvclient|Messaging RecvClient]]
- [[registry|Registry Client]] 

Models:

- [[msg|Messaging Message]]

Results:

- [[clearsignresult|ClearSignResult]]
- [[containersignresult|ContainerSignResult]]
- [[signingresults|SigningResults]]

Operations:

- [[container-sign-operation|Container Sign Operation]]
- [[clear-sign-operation|Clear Sign Operation]]


